@@ -5,7 +5,7 @@ use warnings;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.90';
+$VERSION = '0.91';
 
 #----------------------------------------------------------------------------
 
@@ -60,6 +60,7 @@ keys.
   templates => path to templates directory
   database  => path to SQLite database file
   address   => path to address file
+  mailrc    => path to 01mailrc.txt file
   builder   => path to output file from builder log parser
 
   logfile   => path to logfile
@@ -119,6 +120,7 @@ sub new {
     $self->database( _defined_or( $hash{database},  $cfg->val('MASTER','database' ) ));
     $self->address(  _defined_or( $hash{address},   $cfg->val('MASTER','address'  ) ));
     $self->missing(  _defined_or( $hash{missing},   $cfg->val('MASTER','missing'  ) ));
+    $self->mailrc(   _defined_or( $hash{mailrc},    $cfg->val('MASTER','mailrc'   ) ));
     $self->logfile(  _defined_or( $hash{logfile},   $cfg->val('MASTER','logfile'  ) ));
     $self->logclean( _defined_or( $hash{logclean},  $cfg->val('MASTER','logclean' ), 0 ));
     $self->directory(_defined_or( $hash{directory}, $cfg->val('MASTER','directory') ));
@@ -131,6 +133,7 @@ sub new {
     $self->_log("database =".($self->database  || ''));
     $self->_log("address  =".($self->address   || ''));
     $self->_log("missing  =".($self->missing   || ''));
+    $self->_log("mailrc   =".($self->mailrc    || ''));
     $self->_log("logfile  =".($self->logfile   || ''));
     $self->_log("logclean =".($self->logclean  || ''));
     $self->_log("directory=".($self->directory || ''));
@@ -138,6 +141,7 @@ sub new {
 
     die "Must specify the output directory\n"           unless($self->directory);
     die "Must specify the template directory\n"         unless($self->templates);
+    die "Must specify a valid mailrc path\n"            unless($self->mailrc && -f $self->mailrc);
 
     return $self;
 }
@@ -192,7 +196,7 @@ Returns the print form of a recorded OS name.
 
 __PACKAGE__->mk_accessors(
     qw( directory mainstore leadstore templates database address builder 
-        missing logfile logclean copyright tocopy osnames));
+        missing mailrc logfile logclean copyright tocopy osnames));
 
 sub make_pages {
     my $self = shift;
